@@ -164,7 +164,7 @@ class PersistedRmq(object):
                    keys.append(queue_key)
 
         for key in keys:
-            await self.conn.rpush(queue_key, message)
+            await self.conn.rpush(key, message)
             logging.error(f'往失败队列节点{key}push')
 
 
